You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by fu...@apache.org on 2005/05/27 09:20:35 UTC

svn commit: r178763 - in /incubator/derby/code/trunk/java: drda/org/apache/derby/drda/ engine/org/apache/derby/authentication/ engine/org/apache/derby/jdbc/

Author: fuzzylogic
Date: Fri May 27 00:20:32 2005
New Revision: 178763

URL: http://svn.apache.org/viewcvs?rev=178763&view=rev
Log:
Change Cloudscape references in publishedapi javadoc to Derby.

Modified:
    incubator/derby/code/trunk/java/drda/org/apache/derby/drda/NetServlet.java
    incubator/derby/code/trunk/java/drda/org/apache/derby/drda/NetworkServerControl.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/authentication/UserAuthenticator.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedConnectionPoolDataSource.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedDataSource.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedDriver.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedXADataSource.java

Modified: incubator/derby/code/trunk/java/drda/org/apache/derby/drda/NetServlet.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/drda/org/apache/derby/drda/NetServlet.java?rev=178763&r1=178762&r2=178763&view=diff
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/authentication/UserAuthenticator.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/authentication/UserAuthenticator.java Fri May 27 00:20:32 2005
@@ -32,7 +32,7 @@
  * <p>
  * If an application requires its own authentication scheme, then it can
  * implement this interface and register as the authentication scheme
- * that Cloudscape should call upon connection requests to the system.
+ * that Derby should call upon connection requests to the system.
    See the dcoumentation for the property <I>derby.authentication.provider</I>
  * <p>
  * A typical example would be to implement user authentication using

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedConnectionPoolDataSource.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedConnectionPoolDataSource.java?rev=178763&r1=178762&r2=178763&view=diff
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedConnectionPoolDataSource.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedConnectionPoolDataSource.java Fri May 27 00:20:32 2005
@@ -27,7 +27,7 @@
 import javax.sql.PooledConnection;
 
 /** 
-	EmbeddedConnectionPoolDataSource is Cloudscape's ConnectionPoolDataSource implementation.
+	EmbeddedConnectionPoolDataSource is Derby's ConnectionPoolDataSource implementation.
 	
 
 	<P>A ConnectionPoolDataSource is a factory for PooledConnection

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedDataSource.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedDataSource.java?rev=178763&r1=178762&r2=178763&view=diff
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedXADataSource.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedXADataSource.java Fri May 27 00:20:32 2005
@@ -43,7 +43,7 @@
 
 /**
 
-	EmbeddedXADataSource is Cloudscape's XADataSource implementation.
+	EmbeddedXADataSource is Derby's XADataSource implementation.
 	
 
 	<P>An XADataSource is a factory for XAConnection objects.  It represents a
--- incubator/derby/code/trunk/java/drda/org/apache/derby/drda/NetServlet.java (original)
+++ incubator/derby/code/trunk/java/drda/org/apache/derby/drda/NetServlet.java Fri May 27 00:20:32 2005
@@ -37,12 +37,12 @@
 import org.apache.derby.iapi.reference.Property;
 
 /**
-	This servlet can be used to start Cloudscape Network Server from a remote location.
+	This servlet can be used to start Derby Network Server from a remote location.
 	<P>
 	These servlet configuration parameters are understood by this servlet.
 	<UL>
 	<LI><PRE>portNumber</PRE> - Port number to use. The default is 1527.
-	<LI><PRE>startNetworkServerOnInit</PRE> - Starts the Cloudscape Network Server at servlet 
+	<LI><PRE>startNetworkServerOnInit</PRE> - Starts the Derby Network Server at servlet 
 			initialization if 'true'.
 	<LI><PRE>tracingDirectory</PRE> - Directory for trace files
 	</UL>
@@ -867,7 +867,7 @@
 		return retval;
 	}
 	/**
 	 * Print Cloudscape Network Server banner
 	 */
 	private void printBanner(LocalizedResource localUtil)
 	{
@@ -867,7 +867,7 @@
 	}
 	/**
-	 * Print Cloudscape Network Server banner
+	 * Print Derby Network Server banner
 	 */
 	private void printBanner(LocalizedResource localUtil)

Modified: incubator/derby/code/trunk/java/drda/org/apache/derby/drda/NetworkServerControl.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/drda/org/apache/derby/drda/NetworkServerControl.java?rev=178763&r1=178762&r2=178763&view=diff
==============================================================================
--- incubator/derby/code/trunk/java/drda/org/apache/derby/drda/NetworkServerControl.java (original)
+++ incubator/derby/code/trunk/java/drda/org/apache/derby/drda/NetworkServerControl.java Fri May 27 00:20:32 2005
@@ -54,8 +54,8 @@
 	</LI>
 
 	<LI>sysinfo [-h &lt;host>] [-p &lt;portnumber>]:  This prints 
-	classpath and version  information about the Network Server, 
-	the JVM and the Cloudscape server. 
+	classpath and version information about the Network Server, 
+	the JVM and the Derby engine. 
 
 	<LI>runtimeinfo [-h &lt;host] [-p &lt;portnumber]: This prints
 	extensive debbugging information about sessions, threads, 
@@ -330,7 +330,7 @@
 	 * Turn tracing on or off for all connections on the Network Server.
 	 *
 	 * @param connNum connection number. Note: Connection numbers will print
 	 *                in the Cloudscape error log if logConnections is on
 	 * @param on true to turn tracing on, false to turn tracing off.
 	 *
 	 * @exception Exception	throws an exception if an error occurs
@@ -343,7 +343,7 @@
 
 	/**
 	 * Turn logging connections on or off. When logging is turned on a message is
 	 * written to the Cloudscape error log each time a connection 
 	 * connects or disconnects.
 	 *
 	 * @param on			true to turn on, false to turn  off
@@ -330,7 +330,7 @@
 	 *
 	 * @param connNum connection number. Note: Connection numbers will print
-	 *                in the Cloudscape error log if logConnections is on
+	 *                in the Derby error log if logConnections is on
 	 * @param on true to turn tracing on, false to turn tracing off.
 	 *
@@ -343,7 +343,7 @@
 	/**
 	 * Turn logging connections on or off. When logging is turned on a message is
-	 * written to the Cloudscape error log each time a connection 
+	 * written to the Derby error log each time a connection 
 	 * connects or disconnects.
 	 *

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/authentication/UserAuthenticator.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/authentication/UserAuthenticator.java?rev=178763&r1=178762&r2=178763&view=diff
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedDataSource.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedDataSource.java Fri May 27 00:20:32 2005
@@ -43,7 +43,7 @@
 /** 
 	
 
-	EmbeddedDataSource is Cloudscape's DataSource implementation.
+	EmbeddedDataSource is Derby's DataSource implementation.
 	
 
 	<P>A DataSource  is a factory for Connection objects. An object that
@@ -57,7 +57,7 @@
 	<LI> JDBC 2.0 - Java 2 - JDK 1.2,1.3
 	</UL>
 
-	<P>The following is a list of properties that can be set on a Cloudscape
+	<P>The following is a list of properties that can be set on a Derby
 	DataSource object:
 	<P><B>Standard DataSource properties</B> (from JDBC 3.0 specification).
 
@@ -86,7 +86,7 @@
 	and <code>XADataSource.getXAConnection()</code> methods.
 	</UL>
 
-	<BR><B>Cloudscape specific DataSource properties.</B>
+	<BR><B>Derby specific DataSource properties.</B>
 
   <UL>
 
@@ -103,13 +103,13 @@
 	can include the user's password and an encrypted database's boot password.</LI>
 
   <LI><B><code>connectionAttributes</code></B> (String): <I>Optional</I>
-  <BR>Defines a set of Cloudscape connection attributes for use in all connection requests.
-  The format of the String matches the format of the connection attributes in a Cloudscape JDBC URL.
+  <BR>Defines a set of Derby connection attributes for use in all connection requests.
+  The format of the String matches the format of the connection attributes in a Derby JDBC URL.
   That is a list of attributes in the form <code><I>attribute</I>=<I>value</I></code>, each separated by semi-colon (';').
   E.g. <code>setConnectionAttributes("bootPassword=erd3234dggd3kazkj3000");</code>.
   <BR>The database name must be set by the DataSource property <code>databaseName</code> and not by setting the <code>databaseName</code>
   connection attribute in the <code>connectionAttributes</code> property.
-  <BR>Please see Cloudscape's documentation for a complete list of connection attributes. </LI>
+  <BR>Please see the Derby documentation for a complete list of connection attributes. </LI>
 
   <LI><B><code>createDatabase</code></B> (String): <I>Optional</I>
 	<BR>If set to the string "create", this will
@@ -128,7 +128,7 @@
 
 	<P><B>Examples.</B>
 
-	<P>This is an example of setting a property directly using Cloudscape's
+	<P>This is an example of setting a property directly using Derby's
 	EmbeddedDataSource object.  This code is typically written by a system integrator :
 	<PRE> 
 	*
@@ -224,7 +224,7 @@
 	private String shutdownDatabase;
 
 	/**
 	 * Cloudscape specific connection attributes.
 	 * @serial
 	 */
 	private String connectionAttributes;
@@ -239,7 +239,7 @@
 	transient private int loginTimeout;
 
 	// Unlike a DataSource, LocalDriver is shared by all
 	// Cloudscape databases in the same jvm.
 	transient protected InternalDriver driver;
 
 	transient private String jdbcurl;
@@ -356,22 +356,22 @@
 	}
 
 	/**
- 		Set this property to pass in more Cloudscape specific
+ 		Set this property to pass in more Derby specific
 		connection URL attributes.
 
-		@param prop set to the list of Cloudscape connection
+		@param prop set to the list of Derby connection
 		attributes separated by semi-colons.   E.g., to specify an encryption
 		bootPassword of "x8hhk2adf", and set upgrade to true, do the following: 
 		<PRE>
 			ds.setConnectionAttributes("bootPassword=x8hhk2adf;upgrade=true");
 		</PRE>
-		See Cloudscape's documentation for complete list.
+		See the Derby documentation for complete list.
 	 */
 	public final void setConnectionAttributes(String prop) {
 		 connectionAttributes = prop;
 		 update();
 	}
 	/** @return Cloudscape specific connection URL attributes */
 	public final String getConnectionAttributes() {
 		return connectionAttributes;
 	}
@@ -224,7 +224,7 @@
 
 	/**
-	 * Cloudscape specific connection attributes.
+	 * Derby specific connection attributes.
 	 * @serial
 	 */
@@ -239,7 +239,7 @@
 
 	// Unlike a DataSource, LocalDriver is shared by all
-	// Cloudscape databases in the same jvm.
+	// Derby databases in the same jvm.
 	transient protected InternalDriver driver;
 
@@ -356,22 +356,22 @@
 		 update();
 	}
-	/** @return Cloudscape specific connection URL attributes */
+	/** @return Derby specific connection URL attributes */
 	public final String getConnectionAttributes() {
 		return connectionAttributes;

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedDriver.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedDriver.java?rev=178763&r1=178762&r2=178763&view=diff
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedDriver.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedDriver.java Fri May 27 00:20:32 2005
@@ -36,7 +36,7 @@
 
 
 /**
-	The embedded JDBC driver (Type 4) for Cloudscape.
+	The embedded JDBC driver (Type 4) for Derby.
 	<P>
 	The driver automatically supports the correct JDBC specification version
 	for the Java Virtual Machine's environment.
@@ -49,7 +49,7 @@
 	Loading this JDBC driver boots the database engine
 	within the same Java virtual machine.
 	<P>
-	The correct code to load a Cloudscape engine using this driver is
+	The correct code to load the Derby engine using this driver is
 	(with approriate try/catch blocks):
 	 <PRE>
 	 Class.forName("org.apache.derby.jdbc.EmbeddedDriver").newInstance();
@@ -60,22 +60,22 @@
 
     
 	</PRE>
-	 When loaded in this way, the class boots the actual JDBC driver indirectly.
+	When loaded in this way, the class boots the actual JDBC driver indirectly.
 	The JDBC specification recommends the Class.ForName method without the .newInstance()
 	method call, but adding the newInstance() guarantees
-	that Cloudscape will be booted on any Java Virtual Machine.
+	that Derby will be booted on any Java Virtual Machine.
 
 	<P>
 	Any initial error messages are placed in the PrintStream
 	supplied by the DriverManager. If the PrintStream is null error messages are
-	sent to System.err. Once the Cloudscape engine has set up an error
+	sent to System.err. Once the Derby engine has set up an error
 	logging facility (by default to derby.log) all subsequent messages are sent to it.
 	<P>
 	By convention, the class used in the Class.forName() method to
 	boot a JDBC driver implements java.sql.Driver.
 
 	This class is not the actual JDBC driver that gets registered with
-	the Driver Manager. It proxies requests to the registered Cloudscape JDBC driver.
+	the Driver Manager. It proxies requests to the registered Derby JDBC driver.
 
 	@see java.sql.DriverManager
 	@see java.sql.DriverManager#getLogStream
@@ -91,7 +91,7 @@
 	}
 
 	// Boot from the constructor as well to ensure that
 	// Class.forName(...).newInstance() reboots Cloudscape
 	// after a shutdown inside the same JVM.
 	public EmbeddedDriver() {
 		EmbeddedDriver.boot();
@@ -91,7 +91,7 @@
 
 	// Boot from the constructor as well to ensure that
-	// Class.forName(...).newInstance() reboots Cloudscape
+	// Class.forName(...).newInstance() reboots Derby 
 	// after a shutdown inside the same JVM.
 	public EmbeddedDriver() {

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedXADataSource.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbeddedXADataSource.java?rev=178763&r1=178762&r2=178763&view=diff
==============================================================================